<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../ui/aboutdialog.ui" line="14"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../ui/aboutdialog.ui" line="28"/>
        <source>MovieSchedule</source>
        <translation>MovieSchedule</translation>
    </message>
    <message utf8="true">
        <location filename="../ui/aboutdialog.ui" line="107"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:18pt;&quot;&gt;This software is ©2010 Jochen Becher.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:18pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:18pt;&quot;&gt;Movies, Theaters, Schedules and GPS Locations use &lt;/span&gt;&lt;a href=&quot;http://www.google.com&quot;&gt;&lt;span style=&quot; font-size:18pt; font-weight:600; text-decoration: underline; color:#2eacff;&quot;&gt;Google&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-size:18pt;&quot;&gt; services.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:18pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:14pt;&quot;&gt;This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:18pt;&quot;&gt;Diese Software ist ©2010 Jochen Becher.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:18pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:18pt;&quot;&gt;Filme, Kinos, Startzeiten und GPS Orte benutzen &lt;/span&gt;&lt;a href=&quot;http://www.google.com&quot;&gt;&lt;span style=&quot; font-size:18pt; font-weight:600; text-decoration: underline; color:#2eacff;&quot;&gt;Google&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-size:18pt;&quot;&gt; Dienste.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:18pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:14pt;&quot;&gt;Dieses Programm ist freie Software. Sie können es unter den Bedingungen der GNU General Public License, wie von der Free Software Foundation veröffentlicht, weitergeben und/oder modifizieren, entweder gemäß Version 3 der Lizenz oder (nach Ihrer Option) jeder späteren Version.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message utf8="true">
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;This software is ©2010 Jochen Becher.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:16pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Movies, Theaters, Schedules and GPS Locations use &lt;/span&gt;&lt;a href=&quot;http://www.google.com&quot;&gt;&lt;span style=&quot; font-size:16pt; text-decoration: underline; color:#0000ff;&quot;&gt;Google &lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;services.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:16pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="obsolete">&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Diese Software ist ©2010 Jochen Becher.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:16pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Filme, Kinos, Startzeiten and GPS Orte benutzen &lt;/span&gt;&lt;a href=&quot;http://www.google.com&quot;&gt;&lt;span style=&quot; font-size:16pt; text-decoration: underline; color:#0000ff;&quot;&gt;Google &lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Dienste.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:16pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Dieses Programm ist freie Software. Sie können es unter den Bedingungen der GNU General Public License, wie von der Free Software Foundation veröffentlicht, weitergeben und/oder modifizieren, entweder gemäß Version 3 der Lizenz oder (nach Ihrer Option) jeder späteren Version.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/aboutdialog.ui" line="143"/>
        <source>Contact</source>
        <translation>Kontakt</translation>
    </message>
    <message>
        <location filename="../ui/aboutdialog.ui" line="153"/>
        <source>Done</source>
        <translation>Fertig</translation>
    </message>
</context>
<context>
    <name>ActionController</name>
    <message>
        <location filename="../control/actioncontroller.cpp" line="79"/>
        <location filename="../control/actioncontroller.cpp" line="88"/>
        <location filename="../control/actioncontroller.cpp" line="92"/>
        <source>Adding calendar event failed.</source>
        <translation>Hinzufügen des Kalendereintrags fehlgeschlagen.</translation>
    </message>
    <message>
        <location filename="../control/actioncontroller.cpp" line="83"/>
        <source>%1 (%2 %3) added to your calendar.</source>
        <translation>%1 (%2, %3) zum Kalender hinzugefügt.</translation>
    </message>
    <message>
        <location filename="../control/actioncontroller.cpp" line="109"/>
        <source>Unable to call theater by phone: communication bus not available.</source>
        <translation>Telefonanruf fehlgeschlagen: Keine Kommunikation mit dem Telefon möglich.</translation>
    </message>
    <message>
        <location filename="../control/actioncontroller.cpp" line="114"/>
        <source>Unable to call theater by phone: phone service not available.</source>
        <translation>Telefonanruf fehlgeschlagen: Telefonfunktion steht nicht zur Verfügung.</translation>
    </message>
    <message>
        <location filename="../control/actioncontroller.cpp" line="121"/>
        <source>Unable to call theater by phone: call failed.</source>
        <translation>Telefonanruf fehlgeschlagen: Kein Anruf möglich.</translation>
    </message>
    <message>
        <source>Unable to search in web: communication bus not available.</source>
        <translation type="obsolete">Websuche fehlgeschlagen: Kommunikation mit Browser nicht möglich.</translation>
    </message>
    <message>
        <location filename="../control/actioncontroller.cpp" line="220"/>
        <source>Unable to search in web: browser service not available.</source>
        <translation>Websuche fehlgeschlagen: Browser steht nicht zur Verfügung.</translation>
    </message>
</context>
<context>
    <name>ContextDialog</name>
    <message>
        <location filename="../ui/contextdialog.ui" line="14"/>
        <source>Actions</source>
        <translation>Aktionen</translation>
    </message>
    <message>
        <location filename="../ui/contextdialog.ui" line="35"/>
        <source>Add to Calendar</source>
        <translation>Im Kalender eintragen</translation>
    </message>
    <message>
        <location filename="../ui/contextdialog.ui" line="42"/>
        <source>Call Theater By Phone</source>
        <translation>Kino anrufen</translation>
    </message>
    <message>
        <location filename="../ui/contextdialog.ui" line="49"/>
        <source>Find Route to Theater</source>
        <translation>Weg zum Kino suchen</translation>
    </message>
    <message>
        <location filename="../ui/contextdialog.ui" line="56"/>
        <source>Search Movie in Web</source>
        <translation>Film im Web suchen</translation>
    </message>
    <message>
        <location filename="../ui/contextdialog.ui" line="63"/>
        <source>Search Theater in Web</source>
        <translation>Kino im Web suchen</translation>
    </message>
</context>
<context>
    <name>LocationController</name>
    <message>
        <location filename="../control/locationcontroller.cpp" line="25"/>
        <source>Unable to detect current city.</source>
        <translation>Die nächste Stadt wurde nicht gefunden.</translation>
    </message>
</context>
<context>
    <name>LocationDialog</name>
    <message>
        <location filename="../ui/locationdialog.ui" line="20"/>
        <source>Location</source>
        <translation>Ort</translation>
    </message>
    <message>
        <location filename="../ui/locationdialog.ui" line="34"/>
        <source>Search Near</source>
        <translation>In der Nähe suchen</translation>
    </message>
    <message>
        <location filename="../ui/locationdialog.ui" line="100"/>
        <source>City</source>
        <translation>Stadt</translation>
    </message>
    <message>
        <location filename="../ui/locationdialog.ui" line="135"/>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
</context>
<context>
    <name>MainController</name>
    <message>
        <source>Unable to access network</source>
        <translation type="obsolete">Netzwerk steht nicht zur Verfügung.</translation>
    </message>
    <message>
        <location filename="../control/maincontroller.cpp" line="44"/>
        <source>Unable to access network.</source>
        <translation>Netzwerk steht nicht zur Verfügung.</translation>
    </message>
    <message>
        <location filename="../control/maincontroller.cpp" line="45"/>
        <source>No theaters found near %1.</source>
        <translation>Keine Kinos in der Nähe von %1 gefunden.</translation>
    </message>
    <message>
        <location filename="../control/maincontroller.cpp" line="46"/>
        <source>No movies found near %1.</source>
        <translation>Keine Filme in der Nähe von %1 gefunden.</translation>
    </message>
    <message>
        <location filename="../control/maincontroller.cpp" line="47"/>
        <source>Error on fetching theaters.</source>
        <translation>Fehler beim Lesen der Kinoliste.</translation>
    </message>
    <message>
        <location filename="../control/maincontroller.cpp" line="48"/>
        <source>Error on fetching movies.</source>
        <translation>Fehler beim Lesen der Filmliste.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../ui/mainwindow.cpp" line="75"/>
        <location filename="../ui/mainwindow.cpp" line="133"/>
        <source>Movies</source>
        <translation>Filme</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.cpp" line="76"/>
        <location filename="../ui/mainwindow.cpp" line="125"/>
        <source>Theaters</source>
        <translation>Kinos</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.cpp" line="77"/>
        <source>Location</source>
        <translation>Ort</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.cpp" line="78"/>
        <source>Options</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.cpp" line="79"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.cpp" line="81"/>
        <source>Call By Phone</source>
        <translation>Kino anrufen</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.cpp" line="82"/>
        <source>Find Route</source>
        <translation>Weg zum Kino suchen</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.cpp" line="83"/>
        <location filename="../ui/mainwindow.cpp" line="85"/>
        <source>Search In Web</source>
        <translation>Im Web suchen</translation>
    </message>
    <message>
        <source>Movie-Schedule</source>
        <translation type="obsolete">Kinoprogramm</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="14"/>
        <location filename="../ui/mainwindow.cpp" line="140"/>
        <source>MovieSchedule</source>
        <translation>MovieSchedule</translation>
    </message>
</context>
<context>
    <name>MovieController</name>
    <message>
        <location filename="../control/moviecontroller.cpp" line="35"/>
        <source>No schedule found for %1.</source>
        <translation>Kein Kinoprogramm für %1 gefunden.</translation>
    </message>
    <message>
        <location filename="../control/moviecontroller.cpp" line="36"/>
        <source>Error on fetching movie schedule.</source>
        <translation>Fehler beim Lesen des Kinoprogramms.</translation>
    </message>
</context>
<context>
    <name>MovieWindow</name>
    <message>
        <location filename="../ui/moviewindow.ui" line="14"/>
        <source>Movie</source>
        <translation>Film</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <location filename="../ui/optionsdialog.ui" line="14"/>
        <source>Options</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../ui/optionsdialog.ui" line="22"/>
        <source>Orientation</source>
        <translation>Orientierung</translation>
    </message>
    <message>
        <location filename="../ui/optionsdialog.ui" line="54"/>
        <source>Done</source>
        <translation>Fertig</translation>
    </message>
    <message>
        <location filename="../ui/optionsdialog.cpp" line="32"/>
        <source>Landscape</source>
        <translation>Querformat</translation>
    </message>
    <message>
        <location filename="../ui/optionsdialog.cpp" line="33"/>
        <source>Portrait</source>
        <translation>Hochformat</translation>
    </message>
    <message>
        <location filename="../ui/optionsdialog.cpp" line="34"/>
        <source>Automatic Rotation</source>
        <translation>Automatische Drehung</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../utils/timeutils.cpp" line="79"/>
        <source>Today</source>
        <comment>DayPainter</comment>
        <translation>Heute</translation>
    </message>
    <message>
        <location filename="../utils/timeutils.cpp" line="81"/>
        <source>Tomorrow</source>
        <comment>DayPainter</comment>
        <translation>Morgen</translation>
    </message>
    <message>
        <location filename="../ui/moviepainter.cpp" line="52"/>
        <source>%1min</source>
        <comment>movie duration</comment>
        <translation>%1Min</translation>
    </message>
</context>
<context>
    <name>TheaterController</name>
    <message>
        <location filename="../control/theatercontroller.cpp" line="35"/>
        <source>No schedule found for %1.</source>
        <translation>Kein Kinoprogramm für %1 gefunden.</translation>
    </message>
    <message>
        <location filename="../control/theatercontroller.cpp" line="36"/>
        <source>Error on fetching theater schedule.</source>
        <translation>Fehler beim Lesen des Kinoprogramms.</translation>
    </message>
</context>
<context>
    <name>TheaterWindow</name>
    <message>
        <location filename="../ui/theaterwindow.ui" line="14"/>
        <source>Theater</source>
        <translation>Kino</translation>
    </message>
</context>
</TS>
